```
Usage: vcd vapp network create [OPTIONS] <vapp-name> <name>

Options:
  --subnet <CIDR>                 Network CIDR  [required]
  --description <description>     description
  --dns1 <IP>                     primary DNS IP
  --dns2 <IP>                     secondary DNS IP
  --dns-suffix <Name>             dns suffix
  --ip-range <ip-range-start-ip-range-end>
                                  IP range
  --guest-vlan-allowed-enabled / --guest-vlan-allowed-disabled
                                  guest vlan allowed
  -h, --help                      Show this message and exit.

```
